@@ -36,8 +36,9 @@ class MarketApi(IMarketApi):
 
     def Init(self):
         """初始化"""
-        ret = self.__wsClient.Connect()
-
+        if not self.__wsClient.Connect():
+            logger.error("market connect failed!")
+            return False
         t = threading.Thread(target=self.__AuotReconnect,args=(self.__wsClient,))
         t.start()
         return True
@@ -158,7 +159,7 @@ class MarketApi(IMarketApi):
         resp = httpJsonPost(url,params) 
         strParams = json.dumps(params,ensure_ascii=False)
         if not resp:
-            logger.error("请求应答为空：" + url + "," + strParams)
+            logger.error("response：" + url + "," + strParams)
             return None
         js = json.loads(resp,encoding='utf-8')
         if js.get('error_no') != 0:
@@ -304,7 +305,11 @@ if __name__ == '__main__':
 
     from iqsopenapi.core.events import *
 
-    environment = Environment(None)
+    config = {
+      "runtime": "DEBUG"
+    }
+
+    environment = Environment(config)
 
     event_bus = EventBus()
 
@@ -320,11 +325,11 @@ if __name__ == '__main__':
 
     event_bus.start()
 
-    #ret1 = api.Subscribe("rb2010.SHFE.TICK.0","rb2010.SHFE.BAR.300","rb2005.SHFE.TICK.0")
+    ret1 = api.Subscribe("rb2010.SHFE.TICK.0","rb2010.SHFE.BAR.300","rb2005.SHFE.TICK.0")
 
-    #ret2 = api.Unsubscribe("rb2005.SHFE.TICK.0")
+    ret2 = api.Unsubscribe("rb2005.SHFE.TICK.0")
 
-    ret3 = api.GetHisBar("rb2010",Exchange.SHFE,60,"20200220000000","20200420230000")
+    ret3 = api.GetHisBar("rb2010",Exchange.SHFE,60,"20200423","20200424")
 
     ret4 = api.GetHisTick("rb2010",Exchange.SHFE,"20200423","20200424")
 
